<?php
/**
 * Plugin Name: Free WordPress Google Recaptcha
 * Plugin URI: https://repobase.net/free-wordpress/fwp-recaptcha/
 * Description: Protect your Wordpress forms with Googles Recaptcha.
 * Version: 0.0.1
 * Author: Jacob Brown
 * License: GPL2
 * Text Domain: fwp-recaptcha
 */


<?php
/**
 * Plugin Name: Universal reCAPTCHA
 * Description: Adds Google reCAPTCHA to login, register, comment, and other forms via hooks.
 * Version: 1.0
 * Author: OpenAI
 * License: GPL2
 */

defined('ABSPATH') or die('No script kiddies please.');

define('URC_SITE_KEY', 'your-site-key-here');
define('URC_SECRET_KEY', 'your-secret-key-here');

// Enqueue reCAPTCHA script globally
add_action('wp_enqueue_scripts', 'urc_enqueue_recaptcha');
add_action('login_enqueue_scripts', 'urc_enqueue_recaptcha');

function urc_enqueue_recaptcha() {
    wp_enqueue_script('google-recaptcha', 'https://www.google.com/recaptcha/api.js', [], null, true);
}

// Add reCAPTCHA field to login, register, and comment forms
add_action('login_form', 'urc_display_recaptcha');
add_action('register_form', 'urc_display_recaptcha');
add_action('comment_form_after_fields', 'urc_display_recaptcha');
add_action('comment_form_logged_in_after', 'urc_display_recaptcha');

function urc_display_recaptcha() {
    echo '<div class="g-recaptcha" data-sitekey="' . esc_attr(URC_SITE_KEY) . '"></div>';
}

// Validate login form
add_filter('authenticate', 'urc_verify_recaptcha_on_login', 30, 3);
function urc_verify_recaptcha_on_login($user, $username, $password) {
    if (!urc_is_recaptcha_valid()) {
        return new WP_Error('recaptcha_invalid', __('<strong>ERROR</strong>: Please complete the reCAPTCHA.'));
    }
    return $user;
}

// Validate registration
add_action('registration_errors', 'urc_verify_recaptcha_on_register', 10, 3);
function urc_verify_recaptcha_on_register($errors, $sanitized_user_login, $user_email) {
    if (!urc_is_recaptcha_valid()) {
        $errors->add('recaptcha_invalid', __('ERROR: Please complete the reCAPTCHA.'));
    }
    return $errors;
}

// Validate comment form
add_filter('preprocess_comment', 'urc_verify_recaptcha_on_comment');
function urc_verify_recaptcha_on_comment($commentdata) {
    if (!urc_is_recaptcha_valid()) {
        wp_die(__('ERROR: Please complete the reCAPTCHA.'));
    }
    return $commentdata;
}

// reCAPTCHA validation helper
function urc_is_recaptcha_valid() {
    if (isset($_POST['g-recaptcha-response'])) {
        $response = wp_remote_post('https://www.google.com/recaptcha/api/siteverify', [
            'body' => [
                'secret' => URC_SECRET_KEY,
                'response' => sanitize_text_field($_POST['g-recaptcha-response']),
                'remoteip' => $_SERVER['REMOTE_ADDR'],
            ]
        ]);

        if (!is_wp_error($response)) {
            $data = json_decode(wp_remote_retrieve_body($response), true);
            return isset($data['success']) && $data['success'] === true;
        }
    }
    return false;
}

